@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2017 Pavel Kalvoda <me@pavelkalvoda.com>
+ * Copyright (c) 2014-2019 Pavel Kalvoda <me@pavelkalvoda.com>
  *
  * libcbor is free software; you can redistribute it and/or modify
  * it under the terms of the MIT license. See LICENSE for details.
@@ -16,25 +16,26 @@ extern "C" {
 
 /** Simple stack record for the parser */
 struct _cbor_stack_record {
-	struct _cbor_stack_record *lower;
-	cbor_item_t *item;
-	size_t subitems;
+  struct _cbor_stack_record *lower;
+  cbor_item_t *item;
+  size_t subitems;
 };
 
 /** Stack handle - contents and size */
 struct _cbor_stack {
-	struct _cbor_stack_record *top;
-	size_t size;
+  struct _cbor_stack_record *top;
+  size_t size;
 };
 
 struct _cbor_stack _cbor_stack_init();
 
 void _cbor_stack_pop(struct _cbor_stack *);
 
-struct _cbor_stack_record *_cbor_stack_push(struct _cbor_stack *, cbor_item_t *, size_t);
+struct _cbor_stack_record *_cbor_stack_push(struct _cbor_stack *, cbor_item_t *,
+                                            size_t);
 
 #ifdef __cplusplus
 }
 #endif
 
-#endif //LIBCBOR_STACK_H
+#endif  // LIBCBOR_STACK_H
