@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2017 Pavel Kalvoda <me@pavelkalvoda.com>
+ * Copyright (c) 2014-2019 Pavel Kalvoda <me@pavelkalvoda.com>
  *
  * libcbor is free software; you can redistribute it and/or modify
  * it under the terms of the MIT license. See LICENSE for details.
@@ -14,21 +14,19 @@
 extern "C" {
 #endif
 
-enum _cbor_unicode_status_error {
-	_CBOR_UNICODE_OK,
-	_CBOR_UNICODE_BADCP
-};
+enum _cbor_unicode_status_error { _CBOR_UNICODE_OK, _CBOR_UNICODE_BADCP };
 
 /** Signals unicode validation error and possibly its location */
 struct _cbor_unicode_status {
-	enum _cbor_unicode_status_error status;
-	size_t                          location;
+  enum _cbor_unicode_status_error status;
+  size_t location;
 };
 
-size_t _cbor_unicode_codepoint_count(cbor_data source, size_t source_length, struct _cbor_unicode_status * status);
+size_t _cbor_unicode_codepoint_count(cbor_data source, size_t source_length,
+                                     struct _cbor_unicode_status* status);
 
 #ifdef __cplusplus
 }
 #endif
 
-#endif //LIBCBOR_UNICODE_H
+#endif  // LIBCBOR_UNICODE_H
